:mod:`cf.shell.ipython_view` -- Backend to the console plugin.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: cf.shell.ipython_view
   :members:
   :synopsis: Backend to the console plugin.
